/// This function is safe and correct
pub fn index_1(idx: usize, arr: &[u8]) -> Option<u8>
{
    if idx < arr.len() {
        unsafe {
            Some(*arr.get_unchecked(idx))
        }
    } else {
        None
    }
}
/// This program is now unsound
pub fn index_2(idx: usize, arr: &[u8]) -> Option<u8>
{
    if idx <= arr.len() {
        unsafe {
            Some(*arr.get_unchecked(idx))
        }
    } else {
        None
    }
}
/// The parameters of this function are limited
pub unsafe fn index_3(idx: usize, arr: &[u8]) -> Option<u8>
{
    if idx <= arr.len() {
        unsafe {
            Some(*arr.get_unchecked(idx))
        }
    } else {
        None
    }
}